# Copyright (C) 2018  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information


class PyPiProject:
    """PyPi project representation

    """
    def __init__(self, data):
        self.data = data

    def info(self):
        return {
            'home_page': self.data['info']['home_page'],
            'description': self.data['info']['description'],
            'summary': self.data['info']['summary'],
            'license': self.data['info']['license'],
            'package_url': self.data['info']['package_url'],
            'project_url': self.data['info']['project_url'],
            'upstream': self.data['info']['project_urls']['Homepage'],
        }

    def author(self):
        return {
            'fullname': self.data['info']['author'],
            'name': self.data['info']['author'],
            'email': self.data['info']['author_email']
        }

    def releases(self):
        releases = {}
        for version, release in self.data['releases'].items():
            if isinstance(release, list):
                if len(release) > 1:
                    raise ValueError(  # unexpected so fail so that we
                                       # can fix later
                        'Unexpected list of more than 1 element, failing!')
                release = release[0]
            releases[version] = {
                'name': version,
                'message': release['comment_text'],
                'sha256': release['digests']['sha256'],
                'size': release['size'],
                'filename': release['filename'],
                'url': release['url'],
                'date': release['upload_time'],
            }
        return releases
