# Copyright (C) 2018  The Software Heritage developers
# See the AUTHORS file at the top-level directory of this distribution
# License: GNU General Public License version 3, or any later version
# See top-level LICENSE file for more information

import json

from unittest import TestCase
from nose.tools import istest

from swh.loader.pypi.model import PyPiProject


class ModelTest(TestCase):

    def setUp(self):
        with open('./swh/loader/pypi/tests/test_model_data.json') as f:
            self.data = json.load(f)
        self.project = PyPiProject(self.data)

    @istest
    def info(self):
        actual_info = self.project.info()

        expected_info = {
            'home_page': self.data['info']['home_page'],
            'description': self.data['info']['description'],
            'summary': self.data['info']['summary'],
            'license': self.data['info']['license'],
            'package_url': self.data['info']['package_url'],
            'project_url': self.data['info']['project_url'],
            'upstream': self.data['info']['project_urls']['Homepage'],
        }

        self.assertEqual(expected_info, actual_info)

    @istest
    def author(self):
        actual_author = self.project.author()

        expected_author = {
            'fullname': self.data['info']['author'],
            'name': self.data['info']['author'],
            'email': self.data['info']['author_email'],
        }

        self.assertEqual(expected_author, actual_author)

    @istest
    def releases(self):
        actual_releases = self.project.releases()

        release0 = self.data['releases']['0.1'][0]
        release1 = self.data['releases']['0.1.1'][0]
        self.maxDiff = None
        expected_releases = {
            '0.1': {
                'name': '0.1',
                'message': release0['comment_text'],
                'sha256': release0['digests']['sha256'],
                'size': release0['size'],
                'filename': release0['filename'],
                'url': release0['url'],
                'date': release0['upload_time'],
            },
            '0.1.1': {
                'name': '0.1.1',
                'message': release1['comment_text'],
                'sha256': release1['digests']['sha256'],
                'size': release1['size'],
                'filename': release1['filename'],
                'url': release1['url'],
                'date': release1['upload_time'],
            }
        }

        self.assertEqual(expected_releases, actual_releases)

    @istest
    def releases_unexpected_release_format(self):
        data = self.data.copy()
        data['releases']['0.1'].append({'anything': 'really to break'})

        with self.assertRaisesRegex(ValueError,
                                    'Unexpected list of more than 1'):
            self.project.releases()
